@@ -66,7 +66,13 @@ def jobs(
         state = "completed"
     try:
         jobs = svc.get_jobs(
-            user_name, status, project=project, pipeline=pipeline, limit=num, state=state, context=context,
+            user_name,
+            status,
+            project=project,
+            pipeline=pipeline,
+            limit=num,
+            state=state,
+            context=context,
         )
     except ServerError as e:
         abort(str(e))
