@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
-from click import echo, secho, pass_context, command, argument, option
-import dateutil
-from tabulate import tabulate
 import json
 
+from click import echo, pass_context, command, argument, option
+from tabulate import tabulate
+
 from nextcodecli.utils import dumps, print_tab
 
 
@@ -52,6 +52,7 @@ def pipelines(ctx, pipeline_name, is_raw, is_details, is_manifest):
             print_tab("Description", p['description'])
             print_tab("Script", p['script'])
             print_tab("Revision", p['revision'] or 'latest')
+            print_tab("Storage Type", p['storage_type'] or 'default')
             for i, p in enumerate(p.get('parameters', [])):
                 txt = "%s (%s)" % (p['name'], p['type'])
                 if p.get('required'):
