@@ -7,12 +7,14 @@ import hjson
 import logging
 import subprocess
 from collections import OrderedDict
+import botocore.session
+import dateutil
 
+from nextcode.credentials import generate_credential_struct, creds_to_dict
 from nextcode.packagelocal import package_and_upload
 from nextcode.exceptions import ServerError, UploadError
 
 from nextcodecli.utils import abort
-from nextcodecli.utils import find_aws_credentials
 
 log = logging.getLogger(__name__)
 
@@ -69,9 +71,10 @@ def run(
     If you are running against a debug server that allows direct script execution you
     can use 'custom' for pipeline_name.
     """
-    credentials = creds_to_dict(credentials)
+
     manifest = {}
     params = {}
+    credentials_map = creds_to_dict(credentials)
     if job_filename:
         with open(job_filename, 'r') as f:
             manifest = hjson.load(f)
@@ -82,7 +85,10 @@ def run(
         profile = profile or manifest.get('profile')
         context = context or manifest.get('context')
         params = manifest.get('params', {})
-        credentials = credentials or manifest.get('credentials', {})
+        if not credentials_map:  # If credentials were not passed via th commandline
+            credentials_map = manifest.get('credentials', {})
+    credentials_struct = generate_credential_struct(credentials_map)
+
     try:
         override_params = {}
         for p in parameters:
@@ -101,14 +107,7 @@ def run(
         dict(params),
     )
 
-    creds = {}
-    for upload_name, local_name in credentials.items():
-        cred = find_aws_credentials(local_name)
-        creds[upload_name] = {}
-        creds[upload_name]['aws_access_key_id'] = cred['aws_access_key_id']
-        creds[upload_name]['aws_secret_access_key'] = cred['aws_secret_access_key']
-        if 'region' in cred:
-            creds[upload_name]['region'] = cred['region']
+
 
     if not project_name:
         abort("You must specify PROJECT_NAME")
@@ -151,7 +150,7 @@ def run(
             trace,
             context=context,
             description=description,
-            credentials=creds,
+            credentials=credentials_struct,
             storage_type=storage_type,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
         )
@@ -166,18 +165,3 @@ def run(
         echo("Executing %s..." % ' '.join(cmd))
         subprocess.call(cmd)
 
-
-def creds_to_dict(credentials):
-    """
-    convert a list of string of the form ['upload=joe', 'download=joe']
-    to an  ordered dict of the form {'upload': 'joe', 'download': 'joe'}
-    """
-    ret = OrderedDict()
-    # credentials are supplied on the form 'upload=joe'
-    # 'joe' being the local profile in ~/.aws/credentials
-    # and 'upload' being the name we give the credentials
-    # when forwarding to the workflow-service
-    for cred in credentials:
-        key, value = cred.split('=')
-        ret[key] = value
-    return ret
